"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getBinaryEntry = exports.createConfig = exports.PACT_STANDALONE_VERSION = void 0;
const chalk = require("chalk");
exports.PACT_STANDALONE_VERSION = '3.1.2.2-alpha';
function makeError(msg) {
    return new Error(chalk.red(`Error while locating pact binary: ${msg}`));
}
function createConfig() {
    const CHECKSUM_SUFFIX = '.checksum';
    return {
        binaries: [
            {
                platform: 'win32',
                binary: `pact-${exports.PACT_STANDALONE_VERSION}-windows-x86_64.zip`,
                binaryChecksum: `pact-${exports.PACT_STANDALONE_VERSION}-windows-x86_64.zip${CHECKSUM_SUFFIX}`,
                folderName: `windows-x64-${exports.PACT_STANDALONE_VERSION}`,
            },
            {
                platform: 'darwin',
                arch: 'x64',
                binary: `pact-${exports.PACT_STANDALONE_VERSION}-osx-x86_64.tar.gz`,
                binaryChecksum: `pact-${exports.PACT_STANDALONE_VERSION}-osx-x86_64.tar.gz${CHECKSUM_SUFFIX}`,
                folderName: `darwin-x64-${exports.PACT_STANDALONE_VERSION}`,
            },
            {
                platform: 'darwin',
                arch: 'arm64',
                binary: `pact-${exports.PACT_STANDALONE_VERSION}-osx-arm64.tar.gz`,
                binaryChecksum: `pact-${exports.PACT_STANDALONE_VERSION}-osx-arm64.tar.gz${CHECKSUM_SUFFIX}`,
                folderName: `darwin-arm64-${exports.PACT_STANDALONE_VERSION}`,
            },
            {
                platform: 'linux',
                arch: 'x64',
                binary: `pact-${exports.PACT_STANDALONE_VERSION}-linux-x86_64.tar.gz`,
                binaryChecksum: `pact-${exports.PACT_STANDALONE_VERSION}-linux-x86_64.tar.gz${CHECKSUM_SUFFIX}`,
                folderName: `linux-x64-${exports.PACT_STANDALONE_VERSION}`,
            },
            {
                platform: 'linux',
                arch: 'arm64',
                binary: `pact-${exports.PACT_STANDALONE_VERSION}-linux-arm64.tar.gz`,
                binaryChecksum: `pact-${exports.PACT_STANDALONE_VERSION}-linux-arm64.tar.gz${CHECKSUM_SUFFIX}`,
                folderName: `linux-arm64-${exports.PACT_STANDALONE_VERSION}`,
            },
        ],
    };
}
exports.createConfig = createConfig;
const CONFIG = createConfig();
function getBinaryEntry(platform = process.platform, arch = process.arch) {
    const found = CONFIG.binaries.find((value) => value.platform === platform && (value.arch ? value.arch === arch : true));
    if (found === undefined) {
        throw makeError(`Cannot find binary for platform '${platform}' with architecture '${arch}'.`);
    }
    return found;
}
exports.getBinaryEntry = getBinaryEntry;
//# sourceMappingURL=install.js.map